package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.OrderReworkMapper;
import com.ruoyi.system.domain.OrderRework;
import com.ruoyi.system.service.IOrderReworkService;

/**
 * OrderReworkService业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-14
 */
@Service
public class OrderReworkServiceImpl implements IOrderReworkService 
{
    @Autowired
    private OrderReworkMapper orderReworkMapper;

    /**
     * 查询OrderRework
     * 
     * @param id OrderRework主键
     * @return OrderRework
     */
    @Override
    public OrderRework selectOrderReworkById(Long id)
    {
        return orderReworkMapper.selectOrderReworkById(id);
    }

    /**
     * 查询OrderRework列表
     * 
     * @param orderRework OrderRework
     * @return OrderRework
     */
    @Override
    public List<OrderRework> selectOrderReworkList(OrderRework orderRework)
    {
        return orderReworkMapper.selectOrderReworkList(orderRework);
    }

    /**
     * 新增OrderRework
     * 
     * @param orderRework OrderRework
     * @return 结果
     */
    @Override
    public int insertOrderRework(OrderRework orderRework)
    {
        return orderReworkMapper.insertOrderRework(orderRework);
    }

    /**
     * 修改OrderRework
     * 
     * @param orderRework OrderRework
     * @return 结果
     */
    @Override
    public int updateOrderRework(OrderRework orderRework)
    {
        return orderReworkMapper.updateOrderRework(orderRework);
    }

    /**
     * 批量删除OrderRework
     * 
     * @param ids 需要删除的OrderRework主键
     * @return 结果
     */
    @Override
    public int deleteOrderReworkByIds(Long[] ids)
    {
        return orderReworkMapper.deleteOrderReworkByIds(ids);
    }

    /**
     * 删除OrderRework信息
     * 
     * @param id OrderRework主键
     * @return 结果
     */
    @Override
    public int deleteOrderReworkById(Long id)
    {
        return orderReworkMapper.deleteOrderReworkById(id);
    }
}
